### Editing Multiple Masters

Font masters are listed in the “Layers” palette.
Click the / buttons to show a layer even if it is not currently active.
See Layers for details.

#### Select All Layers Tool

Use the Select All Layers tool  (shortcut Shift-V) to edit the paths of all visible layers at the same  time.
Click the / buttons in the “Layers” palette to show or hide layers.
Switch between the Select and Select All Layers tool by clicking and holding the Select  icon, then choose the desired tool from the menu:

#### Show All Masters

When in Edit View, choose “Edit” → “Show All Masters” to add all master layers of the current glyph to the Edit View tab.
This command also inserts Intermediate and Alternate layers.

#### Keep Layer Selection in Sync

Select the “Edit” → “Keep Layer Selection in Sync” option to keep the current selection when changing masters.
This option only works when working on a compatible glyph.